@@ -24,6 +24,7 @@ def executenb(*args, **kwargs):
         "The 'nbconvert.preprocessors.execute.executenb' function was moved to nbclient.execute. "
         "We recommend importing that library directly.",
         FutureWarning,
+        stacklevel=2,
     )
     return _execute(*args, **kwargs)
 
@@ -41,7 +42,6 @@ class ExecutePreprocessor(Preprocessor, NotebookClient):
         nb = kw.get("nb")
         if nb is None:
             nb = NotebookNode()
-        kw.setdefault("kernel_manager_class", KernelManager)
         Preprocessor.__init__(self, nb=nb, **kw)
         NotebookClient.__init__(self, nb, **kw)
 
